linux-kselftest.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible"
@ 2018-04-10 12:38 colin.king
  2018-04-10 12:38 ` Colin King
  2018-04-10 15:20 ` pbonzini
  0 siblings, 2 replies; 4+ messages in thread
From: colin.king @ 2018-04-10 12:38 UTC (permalink / raw)


From: Colin Ian King <colin.king at canonical.com>

Trivial fix to spelling mistakes in comment and message text

Signed-off-by: Colin Ian King <colin.king at canonical.com>
---
 tools/testing/selftests/kvm/lib/kvm_util.c  | 2 +-
 tools/testing/selftests/kvm/lib/sparsebit.c | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/tools/testing/selftests/kvm/lib/kvm_util.c b/tools/testing/selftests/kvm/lib/kvm_util.c
index 7ca1bb40c498..e213d513dc61 100644
--- a/tools/testing/selftests/kvm/lib/kvm_util.c
+++ b/tools/testing/selftests/kvm/lib/kvm_util.c
@@ -1435,7 +1435,7 @@ vm_paddr_t vm_phy_page_alloc(struct kvm_vm *vm,
 	sparsebit_idx_t pg;
 
 	TEST_ASSERT((paddr_min % vm->page_size) == 0, "Min physical address "
-		"not divisable by page size.\n"
+		"not divisible by page size.\n"
 		"  paddr_min: 0x%lx page_size: 0x%x",
 		paddr_min, vm->page_size);
 
-- 
2.15.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kselftest" in
the body of a message to majordomo at vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

^ permalink raw reply related	[flat|nested] 4+ messages in thread

* [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible"
  2018-04-10 12:38 [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible" colin.king
@ 2018-04-10 12:38 ` Colin King
  2018-04-10 15:20 ` pbonzini
  1 sibling, 0 replies; 4+ messages in thread
From: Colin King @ 2018-04-10 12:38 UTC (permalink / raw)


From: Colin Ian King <colin.king@canonical.com>

Trivial fix to spelling mistakes in comment and message text

Signed-off-by: Colin Ian King <colin.king at canonical.com>
---
 tools/testing/selftests/kvm/lib/kvm_util.c  | 2 +-
 tools/testing/selftests/kvm/lib/sparsebit.c | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/tools/testing/selftests/kvm/lib/kvm_util.c b/tools/testing/selftests/kvm/lib/kvm_util.c
index 7ca1bb40c498..e213d513dc61 100644
--- a/tools/testing/selftests/kvm/lib/kvm_util.c
+++ b/tools/testing/selftests/kvm/lib/kvm_util.c
@@ -1435,7 +1435,7 @@ vm_paddr_t vm_phy_page_alloc(struct kvm_vm *vm,
 	sparsebit_idx_t pg;
 
 	TEST_ASSERT((paddr_min % vm->page_size) == 0, "Min physical address "
-		"not divisable by page size.\n"
+		"not divisible by page size.\n"
 		"  paddr_min: 0x%lx page_size: 0x%x",
 		paddr_min, vm->page_size);
 
diff --git a/tools/testing/selftests/kvm/lib/sparsebit.c b/tools/testing/selftests/kvm/lib/sparsebit.c
index 0c5cf3e0cb6f..b132bc95d183 100644
--- a/tools/testing/selftests/kvm/lib/sparsebit.c
+++ b/tools/testing/selftests/kvm/lib/sparsebit.c
@@ -121,7 +121,7 @@
  *     avoided by moving the setting of the nodes mask bits into
  *     the previous nodes num_after setting.
  *
  *   + Node starting index is evenly divisable by the number of bits
  *     within a nodes mask member.
  *
  *   + Nodes never represent a range of bits that wrap around the
@@ -1741,7 +1741,7 @@ void sparsebit_validate_internal(struct sparsebit *s)
 
 		/* Validate node index is divisible by the mask size */
 		if (nodep->idx % MASK_BITS) {
-			fprintf(stderr, "Node index not divisable by "
+			fprintf(stderr, "Node index not divisible by "
 				"mask size,\n"
 				"  nodep: %p nodep->idx: 0x%lx "
 				"MASK_BITS: %lu\n",
@@ -121,7 +121,7 @@
  *     the previous nodes num_after setting.
  *
- *   + Node starting index is evenly divisable by the number of bits
+ *   + Node starting index is evenly divisible by the number of bits
  *     within a nodes mask member.
  *
diff --git a/tools/testing/selftests/kvm/lib/sparsebit.c b/tools/testing/selftests/kvm/lib/sparsebit.c
index 0c5cf3e0cb6f..b132bc95d183 100644
--- a/tools/testing/selftests/kvm/lib/sparsebit.c
+++ b/tools/testing/selftests/kvm/lib/sparsebit.c
@@ -121,7 +121,7 @@
  *     avoided by moving the setting of the nodes mask bits into
  *     the previous nodes num_after setting.
  *
  *   + Node starting index is evenly divisable by the number of bits
  *     within a nodes mask member.
  *
  *   + Nodes never represent a range of bits that wrap around the
@@ -1741,7 +1741,7 @@ void sparsebit_validate_internal(struct sparsebit *s)
 
 		/* Validate node index is divisible by the mask size */
 		if (nodep->idx % MASK_BITS) {
-			fprintf(stderr, "Node index not divisable by "
+			fprintf(stderr, "Node index not divisible by "
 				"mask size,\n"
 				"  nodep: %p nodep->idx: 0x%lx "
 				"MASK_BITS: %lu\n",
@@ -121,7 +121,7 @@
  *     the previous nodes num_after setting.
  *
- *   + Node starting index is evenly divisable by the number of bits
+ *   + Node starting index is evenly divisible by the number of bits
  *     within a nodes mask member.
  *
-- 
2.15.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kselftest" in
the body of a message to majordomo at vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

^ permalink raw reply related	[flat|nested] 4+ messages in thread

* [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible"
  2018-04-10 12:38 [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible" colin.king
  2018-04-10 12:38 ` Colin King
@ 2018-04-10 15:20 ` pbonzini
  2018-04-10 15:20   ` Paolo Bonzini
  1 sibling, 1 reply; 4+ messages in thread
From: pbonzini @ 2018-04-10 15:20 UTC (permalink / raw)


On 10/04/2018 14:38, Colin King wrote:
> From: Colin Ian King <colin.king at canonical.com>
> 
> Trivial fix to spelling mistakes in comment and message text
> 
> Signed-off-by: Colin Ian King <colin.king at canonical.com>
> ---
>  tools/testing/selftests/kvm/lib/kvm_util.c  | 2 +-
>  tools/testing/selftests/kvm/lib/sparsebit.c | 4 ++--
>  2 files changed, 3 insertions(+), 3 deletions(-)
> 
> diff --git a/tools/testing/selftests/kvm/lib/kvm_util.c b/tools/testing/selftests/kvm/lib/kvm_util.c
> index 7ca1bb40c498..e213d513dc61 100644
> --- a/tools/testing/selftests/kvm/lib/kvm_util.c
> +++ b/tools/testing/selftests/kvm/lib/kvm_util.c
> @@ -1435,7 +1435,7 @@ vm_paddr_t vm_phy_page_alloc(struct kvm_vm *vm,
>  	sparsebit_idx_t pg;
>  
>  	TEST_ASSERT((paddr_min % vm->page_size) == 0, "Min physical address "
> -		"not divisable by page size.\n"
> +		"not divisible by page size.\n"
>  		"  paddr_min: 0x%lx page_size: 0x%x",
>  		paddr_min, vm->page_size);
>  
> diff --git a/tools/testing/selftests/kvm/lib/sparsebit.c b/tools/testing/selftests/kvm/lib/sparsebit.c
> index 0c5cf3e0cb6f..b132bc95d183 100644
> --- a/tools/testing/selftests/kvm/lib/sparsebit.c
> +++ b/tools/testing/selftests/kvm/lib/sparsebit.c
> @@ -121,7 +121,7 @@
>   *     avoided by moving the setting of the nodes mask bits into
>   *     the previous nodes num_after setting.
>   *
> - *   + Node starting index is evenly divisable by the number of bits
> + *   + Node starting index is evenly divisible by the number of bits
>   *     within a nodes mask member.
>   *
>   *   + Nodes never represent a range of bits that wrap around the
> @@ -1741,7 +1741,7 @@ void sparsebit_validate_internal(struct sparsebit *s)
>  
>  		/* Validate node index is divisible by the mask size */
>  		if (nodep->idx % MASK_BITS) {
> -			fprintf(stderr, "Node index not divisable by "
> +			fprintf(stderr, "Node index not divisible by "
>  				"mask size,\n"
>  				"  nodep: %p nodep->idx: 0x%lx "
>  				"MASK_BITS: %lu\n",
> 

Queued, thanks.

Paolo

--
To unsubscribe from this list: send the line "unsubscribe linux-kselftest" in
the body of a message to majordomo at vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

^ permalink raw reply	[flat|nested] 4+ messages in thread

* [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible"
  2018-04-10 15:20 ` pbonzini
@ 2018-04-10 15:20   ` Paolo Bonzini
  0 siblings, 0 replies; 4+ messages in thread
From: Paolo Bonzini @ 2018-04-10 15:20 UTC (permalink / raw)


On 10/04/2018 14:38, Colin King wrote:
> From: Colin Ian King <colin.king at canonical.com>
> 
> Trivial fix to spelling mistakes in comment and message text
> 
> Signed-off-by: Colin Ian King <colin.king at canonical.com>
> ---
>  tools/testing/selftests/kvm/lib/kvm_util.c  | 2 +-
>  tools/testing/selftests/kvm/lib/sparsebit.c | 4 ++--
>  2 files changed, 3 insertions(+), 3 deletions(-)
> 
> diff --git a/tools/testing/selftests/kvm/lib/kvm_util.c b/tools/testing/selftests/kvm/lib/kvm_util.c
> index 7ca1bb40c498..e213d513dc61 100644
> --- a/tools/testing/selftests/kvm/lib/kvm_util.c
> +++ b/tools/testing/selftests/kvm/lib/kvm_util.c
> @@ -1435,7 +1435,7 @@ vm_paddr_t vm_phy_page_alloc(struct kvm_vm *vm,
>  	sparsebit_idx_t pg;
>  
>  	TEST_ASSERT((paddr_min % vm->page_size) == 0, "Min physical address "
> -		"not divisable by page size.\n"
> +		"not divisible by page size.\n"
>  		"  paddr_min: 0x%lx page_size: 0x%x",
>  		paddr_min, vm->page_size);
>  
> diff --git a/tools/testing/selftests/kvm/lib/sparsebit.c b/tools/testing/selftests/kvm/lib/sparsebit.c
> index 0c5cf3e0cb6f..b132bc95d183 100644
> --- a/tools/testing/selftests/kvm/lib/sparsebit.c
> +++ b/tools/testing/selftests/kvm/lib/sparsebit.c
> @@ -121,7 +121,7 @@
>   *     avoided by moving the setting of the nodes mask bits into
>   *     the previous nodes num_after setting.
>   *
> - *   + Node starting index is evenly divisable by the number of bits
> + *   + Node starting index is evenly divisible by the number of bits
>   *     within a nodes mask member.
>   *
>   *   + Nodes never represent a range of bits that wrap around the
> @@ -1741,7 +1741,7 @@ void sparsebit_validate_internal(struct sparsebit *s)
>  
>  		/* Validate node index is divisible by the mask size */
>  		if (nodep->idx % MASK_BITS) {
> -			fprintf(stderr, "Node index not divisable by "
> +			fprintf(stderr, "Node index not divisible by "
>  				"mask size,\n"
>  				"  nodep: %p nodep->idx: 0x%lx "
>  				"MASK_BITS: %lu\n",
> 

Queued, thanks.

Paolo

--
To unsubscribe from this list: send the line "unsubscribe linux-kselftest" in
the body of a message to majordomo at vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2018-04-10 15:20 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2018-04-10 12:38 [PATCH][next] kvm: selftests: fix spelling mistake: "divisable" and "divisible" colin.king
2018-04-10 12:38 ` Colin King
2018-04-10 15:20 ` pbonzini
2018-04-10 15:20   ` Paolo Bonzini

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).